/*
 * Copyright (C) 2003-2014 The Music Player Daemon Project
 * http://www.musicpd.org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include "config.h"
#include "CommandListBuilder.hxx"
#include "client/ClientInternal.hxx"

#include <string.h>

void
CommandListBuilder::Reset()
{
	list.clear();
	size = 0;
	mode = Mode::DISABLED;
}

bool
CommandListBuilder::Add(const char *cmd)
{
	size_t len = strlen(cmd) + 1;
	size += len;
	if (size > client_max_command_list_size)
		return false;

	list.emplace_back(cmd);
	return true;
}
